==> root-cuda-6.28.04-2-x86_64.pkg.tar.zst: etc/root/dictpch/allLinkDefs.h <==
#include "etc/dictpch/core/multiproc/inc/LinkDef.h"
#include "etc/dictpch/core/rint/inc/LinkDef.h"
#include "etc/dictpch/core/thread/inc/LinkDef.h"
#include "etc/dictpch/core/imt/inc/LinkDef.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef1.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef2.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef3.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef_Func.h"
#include "etc/dictpch/math/mathmore/inc/Math/LinkDef.h"
#include "etc/dictpch/math/mathmore/inc/Math/LinkDef_Func.h"
#include "etc/dictpch/math/mathmore/inc/Math/LinkDef_RootFinding.h"
#include "etc/dictpch/math/matrix/inc/LinkDef.h"
#include "etc/dictpch/math/minuit/inc/LinkDef.h"
#include "etc/dictpch/math/minuit2/inc/LinkDef.h"
#include "etc/dictpch/math/physics/inc/LinkDef.h"
#include "etc/dictpch/math/smatrix/inc/LinkDef.h"
#include "etc/dictpch/math/smatrix/inc/LinkDefAll.h"
#include "etc/dictpch/math/smatrix/inc/LinkDefD32.h"
#include "etc/dictpch/math/smatrix/inc/LinkDef.h"
#include "etc/dictpch/math/smatrix/inc/LinkDefAll.h"
#include "etc/dictpch/math/smatrix/inc/LinkDefD32.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector2.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector32.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVectorAll.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector2.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector32.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVectorAll.h"
#include "etc/dictpch/math/genetic/inc/LinkDef.h"
#include "etc/dictpch/math/vecops/inc/LinkDef.h"
#include "etc/dictpch/hist/hist/inc/LinkDef.h"
#include "etc/dictpch/hist/histpainter/inc/LinkDef.h"
#include "etc/dictpch/hist/histv7/inc/LinkDef.h"
#include "etc/dictpch/hist/histdrawv7/inc/LinkDef.h"
#include "etc/dictpch/hist/spectrum/inc/LinkDef.h"
#include "etc/dictpch/hist/spectrumpainter/inc/LinkDef.h"
#include "etc/dictpch/hist/unfold/inc/LinkDef.h"
#include "etc/dictpch/hist/hbook/inc/LinkDef.h"
#include "etc/dictpch/tree/tree/inc/LinkDef.h"
#include "etc/dictpch/tree/treeplayer/inc/LinkDef.h"
#include "etc/dictpch/tree/treeviewer/inc/LinkDef.h"
#include "etc/dictpch/tree/webviewer/inc/LinkDef.h"
#include "etc/dictpch/tree/dataframe/inc/LinkDef.h"
#include "etc/dictpch/tree/ntuple/inc/LinkDef.h"
#include "etc/dictpch/tree/ntupleutil/inc/LinkDef.h"
#include "etc/dictpch/io/io/inc/LinkDef.h"
#include "etc/dictpch/net/net/inc/LinkDef.h"
#include "etc/dictpch/net/netxng/inc/LinkDef.h"
#include "etc/dictpch/graf2d/gpadv7/inc/LinkDef.h"
#include "etc/dictpch/graf2d/primitivesv7/inc/LinkDef.h"
#include "etc/dictpch/graf2d/gpad/inc/LinkDef.h"
#include "etc/dictpch/graf2d/graf/inc/LinkDef.h"
#include "etc/dictpch/graf2d/postscript/inc/LinkDef.h"
#include "etc/dictpch/graf2d/x11/inc/LinkDef.h"
#include "etc/dictpch/graf2d/x11ttf/inc/LinkDef.h"
#include "etc/dictpch/graf2d/asimage/inc/LinkDef.h"
#include "etc/dictpch/graf2d/asimage/inc/LinkDefGui.h"
#include "etc/dictpch/graf2d/asimage/inc/LinkDef.h"
#include "etc/dictpch/graf2d/asimage/inc/LinkDefGui.h"
#include "etc/dictpch/graf2d/gviz/inc/LinkDef.h"
#include "etc/dictpch/graf2d/fitsio/inc/LinkDef.h"
#include "etc/dictpch/graf3d/g3d/inc/LinkDef.h"
#include "etc/dictpch/graf3d/gl/inc/LinkDef.h"
#include "etc/dictpch/gui/gui/inc/LinkDef.h"
#include "etc/dictpch/gui/fitpanel/inc/LinkDef.h"
#include "etc/dictpch/gui/fitpanelv7/inc/LinkDef.h"
#include "etc/dictpch/bindings/tpython/inc/LinkDef.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef1.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef2.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef3.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef4.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef5.h"
#include "etc/dictpch/tmva/tmvagui/inc/LinkDef.h"
#include "etc/dictpch/tmva/pymva/inc/LinkDef.h"
#include "etc/dictpch/tmva/sofie/inc/LinkDef.h"
#include "etc/dictpch/roofit/roofitcore/inc/LinkDef.h"
#include "etc/dictpch/roofit/roofit/inc/LinkDef1.h"
#include "etc/dictpch/roofit/roofitmore/inc/LinkDef.h"
#include "etc/dictpch/roofit/roostats/inc/LinkDef.h"
#include "etc/dictpch/roofit/histfactory/inc/LinkDef.h"
#include "etc/dictpch/roofit/RDataFrameHelpers/inc/LinkDef.h"
#include "etc/dictpch/roofit/xroofit/inc/LinkDef.h"
#include "etc/dictpch/core/base/inc/LinkDef.h"
#include "etc/dictpch/core/base/inc/LinkDef1.h"
#include "etc/dictpch/core/base/inc/LinkDef2.h"
#include "etc/dictpch/core/base/inc/LinkDef3.h"
#include "etc/dictpch/core/cont/inc/LinkDef.h"
#include "etc/dictpch/core/imt/inc/LinkDef.h"
#include "etc/dictpch/core/macosx/inc/LinkDef.h"
#include "etc/dictpch/core/meta/inc/LinkDef.h"
#include "etc/dictpch/core/multiproc/inc/LinkDef.h"
#include "etc/dictpch/core/rint/inc/LinkDef.h"
#include "etc/dictpch/core/thread/inc/LinkDef.h"
#include "etc/dictpch/core/unix/inc/LinkDef.h"
#include "etc/dictpch/core/winnt/inc/LinkDef.h"

==> root-cuda-6.38.00-1-x86_64.pkg.tar.zst: etc/root/dictpch/allLinkDefs.h <==
#include "etc/dictpch/core/imt/inc/LinkDef.h"
#include "etc/dictpch/core/multiproc/inc/LinkDef.h"
#include "etc/dictpch/core/rint/inc/LinkDef.h"
#include "etc/dictpch/core/thread/inc/LinkDef.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef1.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef2.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef3.h"
#include "etc/dictpch/math/mathcore/inc/LinkDef_Func.h"
#include "etc/dictpch/math/mathmore/inc/Math/LinkDef.h"
#include "etc/dictpch/math/mathmore/inc/Math/LinkDef_Func.h"
#include "etc/dictpch/math/mathmore/inc/Math/LinkDef_RootFinding.h"
#include "etc/dictpch/math/matrix/inc/LinkDef.h"
#include "etc/dictpch/math/minuit/inc/LinkDef.h"
#include "etc/dictpch/math/minuit2/inc/LinkDef.h"
#include "etc/dictpch/math/physics/inc/LinkDef.h"
#include "etc/dictpch/math/smatrix/inc/LinkDef.h"
#include "etc/dictpch/math/smatrix/inc/LinkDefAll.h"
#include "etc/dictpch/math/smatrix/inc/LinkDefD32.h"
#include "etc/dictpch/math/smatrix/inc/LinkDef.h"
#include "etc/dictpch/math/smatrix/inc/LinkDefAll.h"
#include "etc/dictpch/math/smatrix/inc/LinkDefD32.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector2.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector32.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVectorAll.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector2.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVector32.h"
#include "etc/dictpch/math/genvector/inc/Math/LinkDef_GenVectorAll.h"
#include "etc/dictpch/math/genetic/inc/LinkDef.h"
#include "etc/dictpch/math/vecops/inc/LinkDef.h"
#include "etc/dictpch/hist/hist/inc/LinkDef.h"
#include "etc/dictpch/hist/histpainter/inc/LinkDef.h"
#include "etc/dictpch/hist/histv7/inc/LinkDef.h"
#include "etc/dictpch/hist/spectrum/inc/LinkDef.h"
#include "etc/dictpch/hist/spectrumpainter/inc/LinkDef.h"
#include "etc/dictpch/hist/hbook/inc/LinkDef.h"
#include "etc/dictpch/tree/tree/inc/LinkDef.h"
#include "etc/dictpch/tree/treeplayer/inc/LinkDef.h"
#include "etc/dictpch/tree/treeviewer/inc/LinkDef.h"
#include "etc/dictpch/tree/ntuplebrowse/inc/LinkDef.h"
#include "etc/dictpch/tree/webviewer/inc/LinkDef.h"
#include "etc/dictpch/tree/dataframe/inc/LinkDef.h"
#include "etc/dictpch/tree/ntuple/inc/LinkDef.h"
#include "etc/dictpch/tree/ntupleutil/inc/LinkDef.h"
#include "etc/dictpch/io/io/inc/LinkDef.h"
#include "etc/dictpch/net/net/inc/LinkDef.h"
#include "etc/dictpch/net/netxng/inc/LinkDef.h"
#include "etc/dictpch/graf2d/gpadv7/inc/LinkDef.h"
#include "etc/dictpch/graf2d/primitivesv7/inc/LinkDef.h"
#include "etc/dictpch/graf2d/gpad/inc/LinkDef.h"
#include "etc/dictpch/graf2d/graf/inc/LinkDef.h"
#include "etc/dictpch/graf2d/postscript/inc/LinkDef.h"
#include "etc/dictpch/graf2d/x11/inc/LinkDef.h"
#include "etc/dictpch/graf2d/x11ttf/inc/LinkDef.h"
#include "etc/dictpch/graf2d/asimage/inc/LinkDef.h"
#include "etc/dictpch/graf2d/asimage/inc/LinkDefGui.h"
#include "etc/dictpch/graf2d/asimage/inc/LinkDef.h"
#include "etc/dictpch/graf2d/asimage/inc/LinkDefGui.h"
#include "etc/dictpch/graf2d/gviz/inc/LinkDef.h"
#include "etc/dictpch/graf2d/fitsio/inc/LinkDef.h"
#include "etc/dictpch/graf3d/g3d/inc/LinkDef.h"
#include "etc/dictpch/graf3d/gl/inc/LinkDef.h"
#include "etc/dictpch/gui/gui/inc/LinkDef.h"
#include "etc/dictpch/gui/fitpanel/inc/LinkDef.h"
#include "etc/dictpch/gui/treemap/inc/LinkDef.h"
#include "etc/dictpch/gui/fitpanelv7/inc/LinkDef.h"
#include "etc/dictpch/bindings/tpython/inc/LinkDef.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef1.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef2.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef3.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef4.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef5.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDefUtils.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef1.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef2.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef3.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef4.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDef5.h"
#include "etc/dictpch/tmva/tmva/inc/LinkDefUtils.h"
#include "etc/dictpch/tmva/tmvagui/inc/LinkDef.h"
#include "etc/dictpch/tmva/pymva/inc/LinkDef.h"
#include "etc/dictpch/tmva/sofie/inc/LinkDef.h"
#include "etc/dictpch/roofit/roofitcore/inc/LinkDef.h"
#include "etc/dictpch/roofit/roofit/inc/LinkDef1.h"
#include "etc/dictpch/roofit/roofitmore/inc/LinkDef.h"
#include "etc/dictpch/roofit/roostats/inc/LinkDef.h"
#include "etc/dictpch/roofit/histfactory/inc/LinkDef.h"
#include "etc/dictpch/roofit/xroofit/inc/LinkDef.h"
#include "etc/dictpch/core/base/inc/LinkDef.h"
#include "etc/dictpch/core/base/inc/LinkDef1.h"
#include "etc/dictpch/core/base/inc/LinkDef2.h"
#include "etc/dictpch/core/base/inc/LinkDef3.h"
#include "etc/dictpch/core/cont/inc/LinkDef.h"
#include "etc/dictpch/core/imt/inc/LinkDef.h"
#include "etc/dictpch/core/macosx/inc/LinkDef.h"
#include "etc/dictpch/core/meta/inc/LinkDef.h"
#include "etc/dictpch/core/multiproc/inc/LinkDef.h"
#include "etc/dictpch/core/rint/inc/LinkDef.h"
#include "etc/dictpch/core/thread/inc/LinkDef.h"
#include "etc/dictpch/core/unix/inc/LinkDef.h"
#include "etc/dictpch/core/winnt/inc/LinkDef.h"
